@@ -62,29 +62,27 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "alloc_8h.html",
-"globals_defs_m.html",
-"globals_i.html",
-"group__pw__client__node.html#ga8f467593dff291edaac0f46531c23aed",
-"group__pw__impl__core.html#ga32f8301c7a43a4c4d418add1e71642a2",
-"group__pw__keys.html#gad7fe1ca68b65df33c09b8d14cfd708b0",
-"group__pw__permission.html#ga77df16320c3bb338666f55b2b21e6e47",
-"group__pw__session__manager.html#ga659e95476b1273ad6b2d247256375df7",
-"group__pwtest.html#gae28b2ed45d205b93298f6c85f9cf6913",
-"group__spa__device.html#ga0176aee6eac7ee89895ab4f4069afa41",
-"group__spa__keys.html#gab67f1f5fc3425c08a37874cbf7ac1afb",
-"group__spa__node.html#ga81ae3a5666e6a8b3b8236f8ff7749ea3",
-"group__spa__param.html#ga9c4f60adda447be6743c1cb662e4f915",
-"group__spa__param.html#gga4077adc9cb334bd78d561f96c04eebbca940b858de739418787236fd591abf505",
-"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaa308342b826a8580020b397f8d4281846",
-"group__spa__pod.html#ga3f71fd97eb4ca17b150a34bf05272307",
-"group__spa__string.html#gab9f2fbcc3c33f77f37e9f00941f387b6",
-"module_8h.html",
-"page_streams.html#sec_create",
-"structpw__endpoint__link__events.html#ac358bf9f098e9a01690fb72901927427",
-"structpw__node.html",
-"structspa__buffer__alloc__info.html",
-"structspa__json.html#ae765edf5a3ac4c7fe5be87c93f62b0c2",
-"structspa__pod__struct.html"
+"group__pw__client.html#gaffa5b807a9674495aa5c14a68d5fd88c",
+"group__pw__global.html#gaf901fcdcb9d2059370fdd9d6ad188c3f",
+"group__pw__keys.html#gaae4d17260ca60c2ab5e2c8d32b989d67",
+"group__pw__node.html#ga91a6a1a257b75f8a6fd5eb6755447a59",
+"group__pw__session__manager.html#ga3e4945a8ef7615d8e4b574209890a68b",
+"group__pwtest.html#ga60aaaf4bca029a7cd77d9e2328cc33b0",
+"group__spa__dbus.html#ga86263eb7e15c01e44c67b4b92c777a45",
+"group__spa__keys.html#ga397212748e5208c2727994b89ab56b04",
+"group__spa__node.html#ga4057156d1eaf9f13cab72a187735ad65",
+"group__spa__param.html#ga7f188485cf47ffb05c8f6be407448f2c",
+"group__spa__param.html#gga4077adc9cb334bd78d561f96c04eebbca4c1b239852626671b53906f9d9b89e42",
+"group__spa__param.html#ggab89b8affc8ad458b2cc10dd9e8423fe7acb6b47253078f2060df6af90fdedaf27",
+"group__spa__pod.html#ga1d4549904c233c319e9a6222d7781948",
+"group__spa__pod.html#gga38ee9b093a1a766cfc3d96db7c28067fa82fbd414410e306dc9e4cf3a2ac4dc78",
+"hook_8h.html",
+"page_spa_design.html#autotoc_md130",
+"structpw__data__loop__events.html#a5ee1e79472b7ab5aab28d40df7a1db0b",
+"structpw__memchunk.html",
+"structspa__audio__info.html",
+"structspa__io__segment.html#ab725d4cd7f8cb1a44abe185ac504fd1c",
+"structspa__pod__object.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
